﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using MongoDB;
using ClownFish;


/// <summary>
/// 操作“商品记录”的业务逻辑层
/// </summary>
public sealed class ProductBLL 
{
	public void Insert(Product product)
	{
		product.ProductID = Guid.NewGuid().ToString("N");

		using( MyMongoDb mm = new MyMongoDb() ) {
			mm.GetCollection<Product>().Insert(product);
		}
	}

	public void Delete(string productId)
	{
		using( MyMongoDb mm = new MyMongoDb() ) {
			mm.GetCollection<Product>().Remove(x => x.ProductID == productId);
		}
	}


	public void Update(Product product)
	{
		using( MyMongoDb mm = new MyMongoDb() ) {
			mm.GetCollection<Product>().Update(product, (x => x.ProductID == product.ProductID));
		}
	}


	public Product GetProductById(string productId)
	{
		using( MyMongoDb mm = new MyMongoDb() ) {
			return mm.GetCollection<Product>().FindOne(x => x.ProductID == productId);
		}
	}


	public List<Product> SearchProduct(string categoryId, string searchWord, PagingInfo pagingInfo)
	{
		using( MyMongoDb mm = new MyMongoDb() ) {
			var collection = mm.GetCollection<Product>();

			var query = from product in collection.Linq()
						select product;

			if( string.IsNullOrEmpty(categoryId) == false && categoryId != "0" )
				query = query.Where(p => p.CategoryID == categoryId);

			if( string.IsNullOrEmpty(searchWord) == false )
				query = query.Where(p => p.ProductName.Contains(searchWord));
			
			return query.OrderBy(x => x.ProductName).GetPagingList<Product>(pagingInfo);
		}
	}


	public void ChangeProductQuantity(string productId, int quantity)
	{
		using( MyMongoDb mm = new MyMongoDb() ) {
			var collection = mm.GetCollection<Product>();

			Product product = collection.FindOne(x => x.ProductID == productId);
			if( product == null )
				return;

			product.Quantity = quantity;
			collection.Update(product, (x => x.ProductID == product.ProductID));
		}
	}

}
